@@ -4,8 +4,8 @@
 ## Author:      Mattia Barbon
 ## Modified by:
 ## Created:     01/10/2000
-## RCS-ID:      $Id: Wx.pm 2552 2009-05-10 07:59:43Z mbarbon $
-## Copyright:   (c) 2000-2009 Mattia Barbon
+## RCS-ID:      $Id: Wx.pm 3052 2011-04-22 06:44:32Z mdootson $
+## Copyright:   (c) 2000-2011 Mattia Barbon
 ## Licence:     This program is free software; you can redistribute it and/or
 ##              modify it under the same terms as Perl itself
 #############################################################################
@@ -21,7 +21,7 @@ use vars qw(@ISA $VERSION $XS_VERSION $AUTOLOAD @EXPORT_OK %EXPORT_TAGS
 $_msw = 1; $_gtk = 2; $_motif = 3; $_mac = 4; $_x11 = 5;
 
 @ISA = qw(Exporter);
-$VERSION = '0.91_01';
+$VERSION = '0.98_01';
 $XS_VERSION = $VERSION;
 $VERSION = eval $VERSION;
 
@@ -38,14 +38,14 @@ sub wxSIZE   { Wx::Size->new( $_[0], $_[1] )  }
 sub wxTheApp { $Wx::wxTheApp }
 
 sub AUTOLOAD {
-  my( $constname );
+  my( $constname, $error );
 
   ($constname = $AUTOLOAD) =~ s<^.*::>{};
   return 0 if $constname eq 'wxVERSION';
 
-  my( $val ) = constant($constname, 0 );
+  my( $val ) = constant( $constname, 0, $error );
 
-  if ($! != 0) {
+  if( $error != 0 ) {
 # re-add this if need support for autosplitted subroutines
 #    $AutoLoader::AUTOLOAD = $AUTOLOAD;
 #    goto &AutoLoader::AUTOLOAD;
@@ -102,39 +102,23 @@ use Wx::Mini;
 _start();
 
 our( $wx_path );
+our( $wx_binary_loader );
 
+# back compat only
 sub _load_file {
-  Wx::wxVERSION() < 2.005 ? DynaLoader::dl_load_file( $_[0], 0 ) :
-                            Wx::_load_plugin( $_[0] );
+  Wx::_load_plugin( $_[0] );
 }
 
-my( $load_fun, $unload_fun ) = ( \&_load_dll, \&_unload_dll );
-
-sub set_load_function { $load_fun = shift }
-sub set_end_function { $unload_fun = shift }
-
 sub load_dll {
-  return if $^O eq 'darwin' || Wx::wxVERSION() < 2.005;
-  goto &$load_fun;
+  $wx_binary_loader->load_dll(@_);
 }
 
 sub unload_dll {
-  return if $^O eq 'darwin' || Wx::wxVERSION() < 2.005;
-  goto &$unload_fun;
+  $wx_binary_loader->unload_dll(@_);
 }
 
 END { unload_dll() }
 
-sub _unload_dll { }
-
-sub _load_dll {
-  local $ENV{PATH} = $wx_path . ';' . $ENV{PATH} if $wx_path;
-  return unless exists $Wx::dlls->{$_[0]} && $Wx::dlls->{$_[0]};
-  my $dll = $Wx::dlls->{$_[0]};
-  $dll = $wx_path . '/' . $dll if $wx_path;
-  Wx::_load_file( $dll );
-}
-
 {
   _boot_Constant( 'Wx', $XS_VERSION );
   _boot_Events( 'Wx', $XS_VERSION );
@@ -158,7 +142,7 @@ use strict 'refs';
 
 *Wx::Window::GetClientSizeWH = \&Wx::Window::GetClientSizeXY;
 
-if( Load() ) {
+if( Load( 1 ) ) {
     SetConstants();
     SetConstantsOnce();
     SetOvlConstants();
@@ -181,11 +165,6 @@ eval( "sub wxGTK() { $_platform == $_gtk }" );
 eval( "sub wxMAC() { $_platform == $_mac }" );
 eval( "sub wxX11() { $_platform == $_x11 }" );
 
-# Mac OS X warning
-if( wxMAC() && $^X !~ m{/wxPerl\.app/} && !$ENV{HARNESS_ACTIVE} ) {
-    warn "On Mac OS X please run scripts with the 'wxPerl' interpreter\n";
-}
-
 require Wx::App;
 require Wx::Event;
 require Wx::Locale;
@@ -243,6 +222,7 @@ sub GetMultipleChoices {
     return @s;
   }
 
+  $dialog->Destroy;
   return;
 }
 
@@ -368,6 +348,36 @@ must be placed in the same directory as the executable file.
       </dependency>
   </assembly>
 
+=head1 Running on Mac OSX
+
+From version 0.98 wxPerl no longer needs to use the special startup
+executable 'wxperl' to run scripts on the Mac. The ordinary perl
+interpreter now works without problems. This is because wxPerl now
+contains code that brings the running application to the front and
+gives it the focus.
+
+In a syntax checking editor you may prevent Wx code from being
+given focus as the front process by setting an environment variable
+
+export WXPERL_OPTIONS=NO_MAC_SETFRONTPROCESS
+
+or 
+
+$ENV{WXPERL_OPTIONS} = 'NO_MAC_SETFRONTPROCESS';
+
+The code that makes the SetFrontProcess call is in Wx::Mini as
+
+Wx::MacSetFrontProcess();
+
+so it is also straightforward to override this method if you wish.
+
+Finally, any code can force the running application to become the
+front process regardless of environment settings by calling the xs
+method directly. (Note the underscore in the method name).
+
+Wx::_MacSetFrontProcess();
+
+
 =head1 AUTHOR
 
 Mattia Barbon <mbarbon@cpan.org>
